# Tn Algo
A set of predefined functions used to write algorithm in the new curricula.

## Installation
```pip install tnalgo```

## How to use it?
Open terminal and type square and then input the integer

## License

© 2020 Mohamed Anis MANI

This repository is licensed under the MIT license. See LICENSE for details.